@@ -29,6 +29,7 @@ typedef struct _FlatpakInstallation FlatpakInstallation;
 
 #include <gio/gio.h>
 #include <flatpak-installed-ref.h>
+#include <flatpak-instance.h>
 #include <flatpak-remote.h>
 
 #define FLATPAK_TYPE_INSTALLATION flatpak_installation_get_type ()
@@ -54,6 +55,9 @@ typedef struct
  * @FLATPAK_UPDATE_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
  * @FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
  * @FLATPAK_UPDATE_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after updating (Since: 0.11.8)
+ * @FLATPAK_UPDATE_FLAGS_NO_TRIGGERS: Don't call triggers after updating. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported files. (Since: 1.0.3)
  *
  * Flags to alter the behavior of flatpak_installation_update().
  */
@@ -63,6 +67,7 @@ typedef enum {
   FLATPAK_UPDATE_FLAGS_NO_PULL          = (1 << 1),
   FLATPAK_UPDATE_FLAGS_NO_STATIC_DELTAS = (1 << 2),
   FLATPAK_UPDATE_FLAGS_NO_PRUNE         = (1 << 3),
+  FLATPAK_UPDATE_FLAGS_NO_TRIGGERS      = (1 << 4),
 } FlatpakUpdateFlags;
 
 /**
@@ -71,6 +76,9 @@ typedef enum {
  * @FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS: Don't use static deltas when pulling
  * @FLATPAK_INSTALL_FLAGS_NO_DEPLOY: Don't install any new builds that might be fetched
  * @FLATPAK_INSTALL_FLAGS_NO_PULL: Don't try to fetch new builds from the remote repo
+ * @FLATPAK_INSTALL_FLAGS_NO_TRIGGERS: Don't call triggers after installing. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported files. (Since: 1.0.3)
  *
  * Flags to alter the behavior of flatpak_installation_install_full().
  */
@@ -79,22 +87,40 @@ typedef enum {
   FLATPAK_INSTALL_FLAGS_NO_STATIC_DELTAS = (1 << 0),
   FLATPAK_INSTALL_FLAGS_NO_DEPLOY        = (1 << 2),
   FLATPAK_INSTALL_FLAGS_NO_PULL          = (1 << 3),
+  FLATPAK_INSTALL_FLAGS_NO_TRIGGERS      = (1 << 4),
 } FlatpakInstallFlags;
 
 /**
  * FlatpakUninstallFlags:
  * @FLATPAK_UNINSTALL_FLAGS_NONE: Default
  * @FLATPAK_UNINSTALL_FLAGS_NO_PRUNE: Don't prune the local OSTree repository after uninstalling
+ * @FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS: Don't call triggers after uninstalling. If used,
+ * the caller must later call flatpak_installation_run_triggers() to update
+ * the exported file. (Since: 1.0.3)
  *
  * Flags to alter the behavior of flatpak_installation_uninstall_full().
  *
  * Since: 0.11.8
  */
 typedef enum {
-  FLATPAK_UNINSTALL_FLAGS_NONE     = 0,
-  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE = (1 << 0),
+  FLATPAK_UNINSTALL_FLAGS_NONE        = 0,
+  FLATPAK_UNINSTALL_FLAGS_NO_PRUNE    = (1 << 0),
+  FLATPAK_UNINSTALL_FLAGS_NO_TRIGGERS = (1 << 1),
 } FlatpakUninstallFlags;
 
+/**
+ * FlatpakLaunchFlags:
+ * @FLATPAK_LAUNCH_FLAGS_NONE: Default
+ * @FLATPAK_LAUNCH_FLAGS_DO_NOT_REAP: Do not reap the child. Use this if you want to wait
+ * for the child with g_child_watch_add(). (Snce: 1.1)
+ *
+ * Flags to alter the behavior of flatpak_installation_launch_full().
+ */
+typedef enum {
+  FLATPAK_LAUNCH_FLAGS_NONE        = 0,
+  FLATPAK_LAUNCH_FLAGS_DO_NOT_REAP = (1 << 0),
+} FlatpakLaunchFlags;
+
 /**
  * FlatpakStorageType:
  * @FLATPAK_STORAGE_TYPE_DEFAULT: default
@@ -172,6 +198,15 @@ FLATPAK_EXTERN gboolean             flatpak_installation_launch (FlatpakInstalla
                                                                  const char          *commit,
                                                                  GCancellable        *cancellable,
                                                                  GError             **error);
+FLATPAK_EXTERN gboolean             flatpak_installation_launch_full (FlatpakInstallation *self,
+                                                                      FlatpakLaunchFlags   flags,
+                                                                      const char          *name,
+                                                                      const char          *arch,
+                                                                      const char          *branch,
+                                                                      const char          *commit,
+                                                                      FlatpakInstance    **instance_out,
+                                                                      GCancellable        *cancellable,
+                                                                      GError             **error);
 FLATPAK_EXTERN GFileMonitor        *flatpak_installation_create_monitor (FlatpakInstallation *self,
                                                                          GCancellable        *cancellable,
                                                                          GError             **error);
@@ -226,6 +261,9 @@ FLATPAK_EXTERN gboolean              flatpak_installation_set_config_sync (Flatp
                                                                            const char          *value,
                                                                            GCancellable        *cancellable,
                                                                            GError             **error);
+FLATPAK_EXTERN gboolean              flatpak_installation_get_min_free_space_bytes (FlatpakInstallation *self,
+                                                                                    guint64             *out_bytes,
+                                                                                    GError             **error);
 FLATPAK_EXTERN char *                flatpak_installation_get_config (FlatpakInstallation *self,
                                                                       const char          *key,
                                                                       GCancellable        *cancellable,
@@ -368,6 +406,9 @@ FLATPAK_EXTERN gboolean          flatpak_installation_cleanup_local_refs_sync (F
 FLATPAK_EXTERN gboolean          flatpak_installation_prune_local_repo (FlatpakInstallation *self,
                                                                         GCancellable        *cancellable,
                                                                         GError             **error);
+FLATPAK_EXTERN gboolean          flatpak_installation_run_triggers (FlatpakInstallation *self,
+                                                                    GCancellable        *cancellable,
+                                                                    GError             **error);
 
 
 #endif /* __FLATPAK_INSTALLATION_H__ */
